@@ -1,5 +1,5 @@
-/* Define this unconditionally */
-#define _XOPEN_SOURCE
+/* Define this if your system supports it */
+#undef _XOPEN_SOURCE
 
 /* Define if you have the <errno.h> header file.  */
 #undef HAVE_SYS_SELECT_H
